pub struct BundleShardAmount {
pub ability_id: AbilityId,
pub amount: i64,
}Expand description
Фиксированная выдача осколков одной способности в шаге бандла.
Fields
ability_id: AbilityIdamount: i64Trait Implementations
Sourceimpl Clone for BundleShardAmount
impl Clone for BundleShardAmount
Sourcefn clone(&self) -> BundleShardAmount
fn clone(&self) -> BundleShardAmount
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BundleShardAmount
impl Debug for BundleShardAmount
Sourceimpl<'de> Deserialize<'de> for BundleShardAmount
impl<'de> Deserialize<'de> for BundleShardAmount
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BundleShardAmount
impl JsonSchema for BundleShardAmount
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BundleShardAmount
impl PartialEq for BundleShardAmount
Sourceimpl Serialize for BundleShardAmount
impl Serialize for BundleShardAmount
Sourceimpl Tsify for BundleShardAmount
impl Tsify for BundleShardAmount
const DECL: &'static str = "/**\n * \u{424}\u{438}\u{43a}\u{441}\u{438}\u{440}\u{43e}\u{432}\u{430}\u{43d}\u{43d}\u{430}\u{44f} \u{432}\u{44b}\u{434}\u{430}\u{447}\u{430} \u{43e}\u{441}\u{43a}\u{43e}\u{43b}\u{43a}\u{43e}\u{432} \u{43e}\u{434}\u{43d}\u{43e}\u{439} \u{441}\u{43f}\u{43e}\u{441}\u{43e}\u{431}\u{43d}\u{43e}\u{441}\u{442}\u{438} \u{432} \u{448}\u{430}\u{433}\u{435} \u{431}\u{430}\u{43d}\u{434}\u{43b}\u{430}.\n */\nexport interface BundleShardAmount {\n ability_id: AbilityId;\n amount: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for BundleShardAmount
impl StructuralPartialEq for BundleShardAmount