pub struct CurrencyBranch {
pub condition: CustomValueCondition,
pub currencies: Vec<CurrencyUnit>,
}Expand description
Одна ветка CurrencyBranchStep: условие + валюты при совпадении.
Fields
condition: CustomValueConditioncurrencies: Vec<CurrencyUnit>Trait Implementations
Sourceimpl Clone for CurrencyBranch
impl Clone for CurrencyBranch
Sourcefn clone(&self) -> CurrencyBranch
fn clone(&self) -> CurrencyBranch
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CurrencyBranch
impl Debug for CurrencyBranch
Sourceimpl<'de> Deserialize<'de> for CurrencyBranch
impl<'de> Deserialize<'de> for CurrencyBranch
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CurrencyBranch
impl JsonSchema for CurrencyBranch
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CurrencyBranch
impl PartialEq for CurrencyBranch
Sourceimpl Serialize for CurrencyBranch
impl Serialize for CurrencyBranch
Sourceimpl Tsify for CurrencyBranch
impl Tsify for CurrencyBranch
const DECL: &'static str = "/**\n * \u{41e}\u{434}\u{43d}\u{430} \u{432}\u{435}\u{442}\u{43a}\u{430} [`CurrencyBranchStep`]: \u{443}\u{441}\u{43b}\u{43e}\u{432}\u{438}\u{435} + \u{432}\u{430}\u{43b}\u{44e}\u{442}\u{44b} \u{43f}\u{440}\u{438} \u{441}\u{43e}\u{432}\u{43f}\u{430}\u{434}\u{435}\u{43d}\u{438}\u{438}.\n */\nexport interface CurrencyBranch {\n condition: CustomValueCondition;\n currencies: CurrencyUnit[];\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for CurrencyBranch
impl StructuralPartialEq for CurrencyBranch